@@ -7,7 +7,7 @@ use utf8;
 
 no if $] >= 5.018, warnings => 'experimental::smartmatch';
 
-our $VERSION = '2.00';
+our $VERSION = '2.01';
 
 # create CONSTANTS for different Return Types
 use constant {
@@ -63,6 +63,9 @@ sub new {
 		},
 	};
 
+	if ( $opt{with_messages} ) {
+		$self->{post}{ReturnList} .= ',messagetext,messagetype';
+	}
 	if ( $opt{with_stops} ) {
 		$self->{post}{StopAlso} = 'True';
 	}
@@ -158,7 +161,20 @@ sub parse_raw_data {
 				);
 			}
 		}
-		if ( $type == TYPE_PREDICTION ) {
+		elsif ( $type == TYPE_MESSAGE ) {
+			push(
+				@{ $self->{messages} },
+				{
+					stop_name => $fields[1],
+					stop_id   => $fields[2],
+
+					# 0 = long text. 2 = short text for station displays?
+					type => $fields[6],
+					text => $fields[7],
+				}
+			);
+		}
+		elsif ( $type == TYPE_PREDICTION ) {
 			push( @{ $self->{stop_names} }, $fields[1] );
 		}
 	}
@@ -193,6 +209,25 @@ sub errstr {
 	return $self->{errstr};
 }
 
+sub messages_by_stop_id {
+	my ( $self, $stop_id ) = @_;
+
+	my @messages = grep { $_->{stop_id} == $stop_id } @{ $self->{messages} };
+	@messages = map { $_->{text} } @messages;
+
+	return @messages;
+}
+
+sub messages_by_stop_name {
+	my ( $self, $stop_name ) = @_;
+
+	my @messages
+	  = grep { $_->{stop_name} eq $stop_name } @{ $self->{messages} };
+	@messages = map { $_->{text} } @messages;
+
+	return @messages;
+}
+
 sub results {
 	my ( $self, %opt ) = @_;
 	my @results;
@@ -347,6 +382,12 @@ sub get_services {
 			name        => 'Aachener Straßenbahn und Energieversorgungs AG',
 			shortname   => 'ASEAG',
 		},
+		{
+			ura_base    => 'http://ura.itcs.mvg-mainz.de/interfaces/ura',
+			ura_version => 1,
+			name        => 'MVG Mainz',
+			shortname   => 'MvgMainz',
+		},
 		{
 			ura_base    => 'http://countdown.api.tfl.gov.uk/interfaces/ura',
 			ura_version => 1,
@@ -384,7 +425,7 @@ API" data providers (e.g. ASEAG)
 
 =head1 VERSION
 
-version 2.00
+version 2.01
 
 =head1 DESCRIPTION
 
@@ -435,6 +476,13 @@ Only request departures for stops which are located up to I<dist> meters
 away from the location specified by I<lon> and I<lat>. Example parameter:
 "50.78496,6.10897,100".
 
+=item B<with_messages> => B<0>|B<1>
+
+When set to B<1> (or any other true value): Also requests stop messages from
+the URA service. Thene can include texts such as "Expect delays due to snow and
+ice" or "stop closed, use replacement stop X instead". Use
+C<< $status->messages >> to access them.
+
 =item B<with_stops> => B<0>|B<1>
 
 When set to B<1> (or any other true value): Also request all stops satisfying
@@ -469,6 +517,16 @@ Travel::Status::DE::URA::Stop(3pm) object describing it.
 Only works when $status was created with B<with_stops> set to a true value.
 Otherwise, undef is returned.
 
+=item $status->messages_by_stop_id($stop_id)
+
+Returns a list of messages for the stop with the ID I<$stop_id>.
+At the moment, each message is a simple string. This may change in the future.
+
+=item $status->messages_by_stop_name($stop_id)
+
+Returns a list of messages for the stop with the name I<$stop_name>.
+At the moment, each message is a simple string. This may change in the future.
+
 =item $status->results(I<%opt>)
 
 Returns a list of Travel::Status::DE::URA::Result(3pm) objects, each describing
